ptf #
//********* Version 2016 *******
@logactivities:  // This version uses log activities for entities.
//********* The database file(s) *******
// This section list the database files that are used by the interactive chemistry editor
// Syntax for local files:                   @database: minteq.txt
// Syntax for files on the internet:         @database: www.meeussen.nl/orchestra/minteqv4.txt

@database: minteqv4.txt
@database: ecnpatch.txt
@database: adsmodels.txt
//********* End of the database file(s) *******


//********* Generate output variables  *******
//********* End of output variables  *******



//********* The variables *******
@globalvar: H2O.logact 0
@Var: DHA_kgl 5.0E-4  //   
@Var: H+.logact 1.0  //  **
@Var: Qmax1 3.51 //   
@Var: Qmax2 5.72 //   
@Var: Vd 1.5  //   
@Var: alpha 0.8  //  
@Var: beta -0.6  // 
@Var: logKH1 4.41 //   
@Var: logKH2 9.12 //   
@Var: nH1 0.604  //   
@Var: nH2 0.244  //   
@Var: p1 1.0  //   
@Var: p2 1.0  //   
@Var: pH NaN  //   
@Var: pHD 4.0  //   
@Var: watervolume 1.0  //   
//********* End of the variables *******


//********* The extra expressions *******
@Stage: (1,  "Vd=10^(alpha+beta*log10(I))")
//********* End of the extra expressions *******

//********* The phases *******
@phase(tot)
@phase(liter)
@link_phase(liter, tot, "watervolume")
@phase(diss)
@link_phase(diss, liter, "1")
@phase(DHA_part_l)
@link_phase(DHA_part_l, diss, "1")
@phase(HA_part)
@link_phase(HA_part, DHA_part_l, "DHA_kgl")
//********* End of the phases *******

// The uiobjects1 class can be used to add user defined content.
// It is literally read and written by the GUI.
@class: uiobjects1(){%
   @include: ..\..\bin\objects2016.txt
@Class: nicamodel(name, parentphase, concentration, donnanVolume){
// define the nica surface phase
@phase(<name>, <parentphase>, <concentration>)
 
//--------------------------------------------------------------------------------------
// Add a donnan phase to this surface, which consist of a phase, linked to the
// surface via volume/kg. The donnan phase is also an entity (act = boltzman factor, sum = charge balance)
// unknown is activity, equation is charge balance at surface = 0
//--------------------------------------------------------------------------------------
@Var: <name>donvol 1.5  // The Donnan volume + default value
//@Calc:(1,"<name>donvol = <donnanVolume>")
@Calc:(1,"<name>donvol = 0")
@phase(<name>_don, <name>, <name>donvol)
@GlobalVar: <name>_don.logact 0
@entity(<name>_don, <name>_don, 0)
//@Uneq2: unknown:(name:, <name>_don.logact,  delta:, 1e-6, type:, lin, step: , 1, default:, 0, iia:, true) equation:(name:, <name>_don.<name>, tol: , 1e-4)
//--------------------------------------------------------------------------------------------
}
%}
@uiobjects1()


@globalvar: I .1
@davies()

//********* The primary entities *******
@Global: pH
@Var: H+.logact  1 **
@Calc:(1, "H+.logact = -pH")
@species(H+, 1)
@primary_entity(H+, pH, -9.0)
@entity(H2O, diss, 55.6 )
@primary_entity(H2O, 0.0)
@species(K+, 1)
@primary_entity(K+, -9.0, diss, 0.01)
@species(NO3-, -1)
@primary_entity(NO3-, -9.0, diss, 0.01)
//******************************

//********* The entities *******

@species(OH-, -1)
@reaction(OH-,  1.00693e-14 , -1.0, H+, 1.0, H2O)

//********* The minerals *******
// This version can use external mineral files.

// Syntax: @xternal_mineral_file: name.txt
//********* End of the minerals *******


//********* Adsorption Models *******

//********* Adsorption Model HA *******************

@nicamodel(HA, HA_part, 1, "Vd")

//** Automatically generated donnan species for HA
@donnanspecies(H+_HA_don, HA_don, H+, 1)
@donnanspecies(K+_HA_don, HA_don, K+, 1)
@donnanspecies(NO3-_HA_don, HA_don, NO3-, -1)
@donnanspecies(OH-_HA_don, HA_don, OH-, -1)

@nicasite(HA1, HA, HA_don, p1, #Qmax1     # )
@nicaspecies(HA1-H, HA1, H+_HA_don, #nH1       #, #nH1       #, logKH1 )

@nicasite(HA2, HA, HA_don, p2, #Qmax2     # )
@nicaspecies(HA2-H, HA2, H+_HA_don, #nH2       #, #nH2       #, logKH2 )
//********* End of Adsorption Model HA *************

//********* End of Adsorption Models *******
